summaryrefslogtreecommitdiffstats
path: root/libemailfunctions
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commitdfb7562b7e607f0ae077a6a436966203029df56d (patch)
treed58abf870c3754458d44a192a0b9e186f506c4ed /libemailfunctions
parentfc5197ec86abe5dc0fa4b48979684845b52357f2 (diff)
downloadtdepim-dfb7562b7e607f0ae077a6a436966203029df56d.tar.gz
tdepim-dfb7562b7e607f0ae077a6a436966203029df56d.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libemailfunctions')
-rw-r--r--libemailfunctions/email.cpp10
-rw-r--r--libemailfunctions/tests/testemail.cpp4
2 files changed, 7 insertions, 7 deletions
diff --git a/libemailfunctions/tests/testemail.cpp b/libemailfunctions/tests/testemail.cpp
index 432334e1b..90a6a862e 100644
--- a/libemailfunctions/tests/testemail.cpp
+++ b/libemailfunctions/tests/testemail.cpp
@@ -183,10 +183,10 @@ int main(int argc, char *argv[])
checkGetNameAndEmail( "(David Faure) faure@kde.org", "David Faure", "faure@kde.org", true );
checkGetNameAndEmail( "My Name (me) <me@home.net>", "My Name (me)", "me@home.net", true ); // #93513
- // Nested tqparenthesis as per https://intevation.de/roundup/kolab/issue858
+ // Nested parenthesis as per https://intevation.de/roundup/kolab/issue858
checkGetNameAndEmail( "faure@kde.org (David (The Man) Faure)", "David (The Man) Faure", "faure@kde.org", true );
- // Double-quotes inside tqparenthesis
+ // Double-quotes inside parenthesis
checkGetNameAndEmail( "faure@kde.org (David \"Crazy\" Faure)", "David \"Crazy\" Faure", "faure@kde.org", true );
checkGetNameAndEmail( "(David \"Crazy\" Faure) faure@kde.org", "David \"Crazy\" Faure", "faure@kde.org", true );
diff --git a/libemailfunctions/email.cpp b/libemailfunctions/email.cpp
index f5c35c17f..78de8f8de 100644
--- a/libemailfunctions/email.cpp
+++ b/libemailfunctions/email.cpp
@@ -32,7 +32,7 @@ TQStringList KPIM::splitEmailAddrList(const TQString& aStr)
{
// Features:
// - always ignores quoted characters
// - ignores everything (including tqparentheses and commas)
// inside quoted strings
// - supports nested comments
// - ignores everything (including double quotes and commas)
@@ -729,12 +729,12 @@ bool KPIM::getNameAndMail(const TQString& aStr, TQString& name, TQString& mail)
// and outside of quoted text behind the trailing '>'.
bInComment = false;
bInQuotesOutsideOfEmail = false;
- int tqparenthesesNesting = 0;
+ int parenthesesNesting = 0;
for( i = iAd+1; len > i; ++i ) {
c = aStr[i];
if( bInComment ){
if( ')' == c ){
- if ( --tqparenthesesNesting == 0 ) {
+ if ( --parenthesesNesting == 0 ) {
bInComment = false;
if( !name.isEmpty() )
name.append( ' ' );
@@ -745,7 +745,7 @@ bool KPIM::getNameAndMail(const TQString& aStr, TQString& name, TQString& mail)
} else {
if( '(' == c ) {
// nested "("
- ++tqparenthesesNesting;
+ ++parenthesesNesting;
}
name.append( c ); // all comment stuff is part of the name
}
@@ -772,7 +772,7 @@ bool KPIM::getNameAndMail(const TQString& aStr, TQString& name, TQString& mail)
case '(':
if( !name.isEmpty() )
name.append( ' ' );
- if ( ++tqparenthesesNesting > 0 )
+ if ( ++parenthesesNesting > 0 )
bInComment = true;
break;
default:
@@ -32,7 +32,7 @@ TQStringList KPIM::splitEmailAddrList(const TQString& aStr)
// Features:
// - always ignores quoted characters
- // - ignores everything (including tqparentheses and commas)
+ // - ignores everything (including parentheses and commas)
// inside quoted strings
// - supports nested comments